==> djaodjin-saas-0.1.4.tar.gz: djaodjin-saas-0.1.4/saas/templates/saas/agreements/legal_terms_of_use.md <==
{{organization.full_name}} Terms of Use
=======================================

By using {{site.domain}} web site (&quot;Service&quot;), you are agreeing
to be bound by the following terms and conditions (&quot;Terms of Use&quot;).

IF YOU DO NOT AGREE WITH THESE TERMS AND CONDITIONS, YOU MUST NOT ACCEPT
THIS AGREEMENT AND MAY NOT USE THE SERVICE.

Violations of any of the terms below will result in the termination of
your Account. You agree to use the Service at your own risk.

1. Account Terms
----------------

1.1 Your user account may only be used by one person. A single account shared
    by multiple users is not permitted. Registration of a user account is
    free so please create as many user accounts as necessary for your
    productive use of the Service.

1.2 You are responsible for maintaining the security of your username
    and password. {{organization.full_name}} cannot and will not be liable
    for any loss or damage from your failure to comply with this security
    obligation.

1.3 You must not use the Service to carry on any illegal or unauthorized
    activities (including but not limited to copyright or trademark
    infringements).

2. Payment and Refunds
----------------------

2.1 Beyond the initial trial credit, you must enter a valid credit card
    to pay the monthly balance due on an Organization's account.

2.2 There will be no refunds for payments of the monthly usage charges.

3. Cancellation and Termination
-------------------------------

3.1 You are solely responsible for properly canceling accounts. An email
    or phone request to cancel an account is not considered cancellation.
    You can cancel an account at any time by clicking on the associated
    &quot;Delete&quot; button. It is a simple no questions asked cancellation
    procedure.

3.2 If you decide to delete an Account, all of the Content associated with
    that Account will be immediately deleted from the Service. This information
     can not be recovered once it has been deleted.

3.3 {{organization.full_name}}, in its sole discretion, has the right to suspend
    or terminate an Account at any time.

3.4 {{organization.full_name}} reserves the right to refuse service to anyone
    for any reason at any time.

4. Copyright and Content Ownership
----------------------------------

4.1 We claim no intellectual property rights over the material you provide
    to the Service. Your materials uploaded remain yours.

4.2 You shall defend {{organization.full_name}} against any claim, demand,
    suit or proceeding made or brought against {{organization.full_name}}
    that Your Content, or Your use of the Service infringes or misappropriates
    the intellectual property rights of a third party or violates applicable
    laws.

4.3 You shall indemnify {{organization.full_name}} for any damages finally
    awarded against, and for reasonable attorney’s fees incurred by,
    {{organization.full_name}} in connection with any such claim, demand, suit
    or proceeding; provided, that {{organization.full_name}}

<ul>
	(1) promptly gives You written notice of the claim, demand, suit
    or proceeding.
</ul>

<ul>
	(2) gives You sole control of the defense and settlement of the claim,
    demand, suit or proceeding (provided that You may not settle any claim,
    demand, suit or proceeding unless the settlement unconditionally
    releases {{organization.full_name}} of all liability).
</ul>

<ul>
	(3) provides to You all reasonable assistance, at Your expense.
</ul>

5. Privacy
----------

5.1 We solely collect information used to provide and improve the Service,
    including but not limited to e-mail addresses.

5.2 We will not sell for profit any personally identifiable information
    we collect to third-parties.

5.3 We may disclose personally identifiable information under special
    circumstances, such as to comply with subpoenas or when your
    actions violate these Terms of Use.

5.4 A cookie is a small amount of data, which often includes an anonymous
    unique identifier that is stored on your hard-drive by your browser
    and temporary authenticate you to the Service. Cookies are required
    to use the Service.

5.5 The Internet is a complex system. You understand that You Content
    is transmitted, stored and manipulated using third-party networks
    and devices {{organization.full_name}} as no control over.
    We do a reasonable attempt at keeping your private and secure in
    the best of our abilities.

6. General Conditions
---------------------

6.1 You use the Service at your own risk. The service is provided on
    an &quot;as is&quot; and &quot;as available&quot; basis.

6.2 You agree not to reproduce, duplicate, modify, sell or resell the Service
    without the express written permission by {{organization.full_name}}.

6.3 Be nice, just do not hack into the Service or falsely imply that you are
    associated with the Service, {{organization.full_name}}, or any other
    {{organization.full_name}} service.

6.4 Questions about the Terms of Use should be sent to {{organization.email}}.

==> djaodjin-saas-0.1.7.tar.gz: djaodjin-saas-0.1.7/saas/templates/saas/agreements/legal_terms_of_use.md <==
{{organization.printable_name}} Terms of Use
=======================================

By using {{site.domain}} web site (&quot;Service&quot;), you are agreeing
to be bound by the following terms and conditions (&quot;Terms of Use&quot;).

IF YOU DO NOT AGREE WITH THESE TERMS AND CONDITIONS, YOU MUST NOT ACCEPT
THIS AGREEMENT AND MAY NOT USE THE SERVICE.

Violations of any of the terms below will result in the termination of
your Account. You agree to use the Service at your own risk.

1. Account Terms
----------------

1.1 Your user account may only be used by one person. A single account shared
    by multiple users is not permitted. Registration of a user account is
    free so please create as many user accounts as necessary for your
    productive use of the Service.

1.2 You are responsible for maintaining the security of your username
    and password. {{organization.printable_name}} cannot and will not be liable
    for any loss or damage from your failure to comply with this security
    obligation.

1.3 You must not use the Service to carry on any illegal or unauthorized
    activities (including but not limited to copyright or trademark
    infringements).

2. Payment and Refunds
----------------------

2.1 Beyond the initial trial credit, you must enter a valid credit card
    to pay the monthly balance due on an Organization's account.

2.2 There will be no refunds for payments of the monthly usage charges.

3. Cancellation and Termination
-------------------------------

3.1 You are solely responsible for properly canceling accounts. An email
    or phone request to cancel an account is not considered cancellation.
    You can cancel an account at any time by clicking on the associated
    &quot;Delete&quot; button. It is a simple no questions asked cancellation
    procedure.

3.2 If you decide to delete an Account, all of the Content associated with
    that Account will be immediately deleted from the Service. This information
     can not be recovered once it has been deleted.

3.3 {{organization.printable_name}}, in its sole discretion, has the right to suspend
    or terminate an Account at any time.

3.4 {{organization.printable_name}} reserves the right to refuse service to anyone
    for any reason at any time.

4. Copyright and Content Ownership
----------------------------------

4.1 We claim no intellectual property rights over the material you provide
    to the Service. Your materials uploaded remain yours.

4.2 You shall defend {{organization.printable_name}} against any claim, demand,
    suit or proceeding made or brought against {{organization.printable_name}}
    that Your Content, or Your use of the Service infringes or misappropriates
    the intellectual property rights of a third party or violates applicable
    laws.

4.3 You shall indemnify {{organization.printable_name}} for any damages finally
    awarded against, and for reasonable attorney’s fees incurred by,
    {{organization.printable_name}} in connection with any such claim, demand, suit
    or proceeding; provided, that {{organization.printable_name}}

<ul>
	(1) promptly gives You written notice of the claim, demand, suit
    or proceeding.
</ul>

<ul>
	(2) gives You sole control of the defense and settlement of the claim,
    demand, suit or proceeding (provided that You may not settle any claim,
    demand, suit or proceeding unless the settlement unconditionally
    releases {{organization.printable_name}} of all liability).
</ul>

<ul>
	(3) provides to You all reasonable assistance, at Your expense.
</ul>

5. Privacy
----------

5.1 We solely collect information used to provide and improve the Service,
    including but not limited to e-mail addresses.

5.2 We will not sell for profit any personally identifiable information
    we collect to third-parties.

5.3 We may disclose personally identifiable information under special
    circumstances, such as to comply with subpoenas or when your
    actions violate these Terms of Use.

5.4 A cookie is a small amount of data, which often includes an anonymous
    unique identifier that is stored on your hard-drive by your browser
    and temporary authenticate you to the Service. Cookies are required
    to use the Service.

5.5 The Internet is a complex system. You understand that You Content
    is transmitted, stored and manipulated using third-party networks
    and devices {{organization.printable_name}} as no control over.
    We do a reasonable attempt at keeping your private and secure in
    the best of our abilities.

6. General Conditions
---------------------

6.1 You use the Service at your own risk. The service is provided on
    an &quot;as is&quot; and &quot;as available&quot; basis.

6.2 You agree not to reproduce, duplicate, modify, sell or resell the Service
    without the express written permission by {{organization.printable_name}}.

6.3 Be nice, just do not hack into the Service or falsely imply that you are
    associated with the Service, {{organization.printable_name}}, or any other
    {{organization.printable_name}} service.

6.4 Questions about the Terms of Use should be sent to {{organization.email}}.
